==> eva-sdk-js-1.0.199.tgz: package/gulp/bundle.js <==
"use strict";

var gulp         = require( "gulp"                       );
var concat       = require( "gulp-concat"                );
var rollup       = require( "rollup"                     ).rollup;
var nodeResolve  = require( "rollup-plugin-node-resolve" );
var commonjs     = require( "rollup-plugin-commonjs"     );
var dtsBundle    = require( "dts-bundle"                 );
var pkg          = require( "../package.json"            );
gulp             = require( "gulp-help"          )( gulp );

gulp.task( "bundle", "Bundles the TypeScript modules using rollup in ES5/UMD format",  function()
{
    return rollup(
    {
        input:   "src/index.js",
        plugins: [
            commonjs(),
            nodeResolve( { jsnext: true } )
            // uglify()
        ]
    } )
    .then( function ( bundle )
        {
            return bundle.write(
            {
                format:         "umd",
                name:           "EvaSDK",
                exports:        "named",
                file:           "dist/bundle.js",
                globals:        { crypto: "crypto" },
                sourcemap:      true,
                declaration:    true
            } );
        }
    );
} );

gulp.task( "bundle_dts", "Bundles the typescript definition files for @types support", function()
{
    // First build the bundle.d.ts based on the entry point code
    //
    dtsBundle.bundle( {
        name:                 pkg.name,
        main:                 "src/index.d.ts",
        baseDir:              "./",
        out:                  "dist/index.d.ts",
        exclude:              /.*node_modules.*/,
        outputAsModuleFolder: true,
        externals:            true,
        verbose:              false
    } );

    // Concat the EVA typings into the final bundle.d.ts
    //
    gulp.src( [ "dist/index.d.ts", "typings/*.d.ts" ] )
    .pipe( concat( "bundle.d.ts" ) )
    .pipe( gulp.dest( "dist" ) );
} );

==> eva-sdk-js-4.7.2.tgz: package/gulp/bundle.js <==
"use strict";

var gulp         = require( "gulp"                       );
var concat       = require( "gulp-concat"                );
var rollup       = require( "rollup"                     ).rollup;
var nodeResolve  = require( "rollup-plugin-node-resolve" );
var commonjs     = require( "rollup-plugin-commonjs"     );
var dtsBundle    = require( "dts-bundle"                 );
var pkg          = require( "../package.json"            );
gulp             = require( "gulp-help"          )( gulp );

gulp.task( "bundle", "Bundles the TypeScript modules using rollup in ES5/UMD format",  function()
{
    return rollup(
    {
        input:   "src/index.js",
        plugins: [
            commonjs(),
            nodeResolve( { jsnext: true } )
            // uglify()
        ]
    } )
    .then( function ( bundle )
        {
            return bundle.write(
            {
                format:         "umd",
                name:           "EvaSDK",
                exports:        "named",
                file:           "dist/bundle.js",
                globals:        { crypto: "crypto" },
                sourcemap:      true
            } );
        }
    );
} );

gulp.task( "bundle_dts", "Bundles the typescript definition files for @types support", function()
{
    // First build the bundle.d.ts based on the entry point code
    //
    dtsBundle.bundle( {
        name:                 pkg.name,
        main:                 "src/index.d.ts",
        baseDir:              "./",
        out:                  "dist/index.d.ts",
        exclude:              /.*node_modules.*/,
        outputAsModuleFolder: true,
        externals:            true,
        verbose:              false
    } );

    // Concat the EVA typings into the final bundle.d.ts
    //
    gulp.src( [ "dist/index.d.ts", "typings/*.d.ts" ] )
    .pipe( concat( "bundle.d.ts" ) )
    .pipe( gulp.dest( "dist" ) );
} );
